@@ -1,11 +1,92 @@
 //   -*- mode: c++; -*-
-#include <String.h>
-#include <Regex.h>
+// #include <String.h>
+
+//#include <Regex.h>
+#include "regex-c.h"
 #include <iostream.h>
 #include <fstream.h>
 #include <vector.h>
 
-#define MAX_LINE 1024  //this isn't actually used by adString 
+#define MAX_LINE 10240  
+
+
+// ************* String.h replacement code:
+class Regex;
+class String;
+
+class Regex{
+  struct re_pattern_buffer* patt;
+public:
+  Regex(const char *s);
+  struct re_pattern_buffer* pattern() const {return patt;};
+};
+
+class String{
+  vector<char> buf;
+public:
+  String();
+  String(const String&);
+  String(char c);
+  String(const char *s);
+
+  unsigned int length() const;
+
+  const char *chrstr() const;
+  String at(int pos, int len) const;
+  String after(int i) const;
+  String after(char *, int startpos=0) const;
+  String before(int) const;
+  String before(char *, int startpos=0) const;
+  String before(char, int startpos=0) const;
+
+  int index(char c, int startpos=0) const;
+  int index(const char *s, int startpos=0) const;
+  int index(const String &s, int startpos=0) const;
+  bool contains(const String&, int startpos=-1) const;
+  bool contains(const char *, int startpos=-1) const;
+  bool contains(const Regex& r, int startpos=0) const;
+  bool contains(char, int startpos=-1) const;
+  
+  void del(int pos, int len);
+  
+  operator const char*() const;
+  String &operator +=(char c);
+  String &operator +=(const char *s);
+  String &operator +=(const String &);
+  char &operator [](int);
+  const char &operator [](int) const;
+
+  friend String     upcase(const String& x);
+  friend bool operator == (const String &x, const String &y);
+  friend bool operator != (const String &x, const String &y);
+  friend bool operator <  (const String &x, const String &y);
+  friend bool operator >  (const String &x, const String &y);
+  friend bool operator <= (const String &x, const String &y);
+  friend bool operator >= (const String &x, const String &y);
+
+  friend int     readline(istream& s, String& x, 
+                             char terminator = '\n');
+                             //,int discard_terminator = 1);
+};
+
+
+ostream &operator<<(ostream &, const String &s);
+
+String operator +  (const String &x, const String &y);
+bool operator == (const String &x, const String &y);
+bool operator != (const String &x, const String &y);
+bool operator <  (const String &x, const String &y);
+bool operator >  (const String &x, const String &y);
+bool operator <= (const String &x, const String &y);
+bool operator >= (const String &x, const String &y);
+
+String upcase(const String& x);
+int readline(istream& s, String& x, 
+		char terminator = '\n');//,int discard_terminator = 1);
+
+
+// ************* "own" string handling code:
+
 
 class parsestream;
 class parseinfo{
@@ -81,6 +162,7 @@ class parsestream:public parseinfo{
   istream *current_istr(){return i[i.size()-1];};
   void close_file();
   void new_file(const String &s);
+  bool stdin_file;
 public:
   init(istream &in){
     i.push_back(&in); 
@@ -95,6 +177,7 @@ public:
     init(in);
     filename()="(probably) stdin";
     in_constructor=false;
+    stdin_file=true;
   };
   parsestream(const String &s){
     ifstream *f=new ifstream(s);
@@ -103,12 +186,13 @@ public:
     if(fname.size())
       fname[fname.size()-1]=s;
     in_constructor=false;
+    stdin_file=false;
   };
   ~parsestream(){
     //delete i;
   };
   bool good(){
-    return i.size()&&current_istr() && (*current_istr());
+    return i.size();//&&current_istr() && (*current_istr());
   };
   char get_char();
   char put_back(char);
