@@ -46,7 +46,7 @@ void usage(){
       <<"         Install menu entries in files filenames"<<endl
       <<"  install-fvwmgenmenu configfile --remove  menuids"<<endl
       <<"         Remove menuid's from menu"<<endl
-      <<"For more info, please read /usr/doc/menu/README"<<endl;
+      <<"For more info, please read /usr/doc/menu/html"<<endl;
   exit(1);
 }
 void donotuseoldinstall(){
@@ -55,7 +55,7 @@ void donotuseoldinstall(){
       <<"other menumanagers. Please use --install-file $filename,"<<endl
       <<"if you must use this programme, or, better, use update-menus,"<<endl
       <<"the wrapper that's supposed to execute this programme"<<endl
-      <<"See also /usr/doc/menu/README"<<endl;
+      <<"See also /usr/doc/menu/html"<<endl;
   exit(1);
 }
 
