@@ -101,22 +101,25 @@ int check_dir(String s){
   if(dodebug)
     cerr<<"CHECK_DIR: "<<s<<endl;
   while(s.length()){
-    i=s.index('/');
+    i=s.index('/',1);
     if(i>=0){
-      t=s.before('/')+'/';
+      t=s.before('/', 1)+'/';
       for(; ((unsigned int)i<s.length()) && (s[i]=='/'); i++);
       s=s.after(i-1);
     } else {
       t=s;
       s="";
     }
-    if(chdir(t)){
+    if(chdir(t)<0){
       if(dodebug)
 	cerr<<"MKDIR "<<t<<endl;
       if(mkdir(t,0755))
 	throw dir_createerror(t);
       if(chdir(t))
 	throw dir_createerror(t);
+    } else {
+      if(dodebug)
+	cerr<<" dir "<<t<<" already exists "<<endl;
     }
   }
   return !s.length();
@@ -216,7 +219,7 @@ func_str::func_str(parsestream &i){
   i.put_back(c);
   i.skip_char(')');
   if(args.size()!=(unsigned int)f->nargs())
-    throw narg_mismatch(&i, &(name[0]));
+    throw narg_mismatch(&i, name);
 }
 
 
@@ -387,7 +390,8 @@ ostream &escfirst_func::output(ostream &o, vector<cat_str *> &args,
   int  i;
 
   for(i=0;(unsigned int)i!=s.length();i++){
-    if(esc.contains(s[i])){
+    if(esc.length() && esc.contains(s[i])){
+      t=s.before(i);
       t+=args[2]->soutput(menuentry);
       t+=s.after(i-1);
       break;
@@ -660,7 +664,7 @@ configinfo::configinfo(parsestream &i){
   linenumber=1;
   treew="c(m)";
   prerun=postrun=genmenu=hkexclude=startmenu=endmenu=submenutitle=NULL;
-  preout="#Automatically generated file. Do not edit (see /usr/doc/menu/README)\n\n";
+  preout="#Automatically generated file. Do not edit (see /usr/doc/menu/html/index.html)\n\n";
   roots="/Debian";
   try{
     while(1){
@@ -782,7 +786,7 @@ ostream &configinfo::debuginfo(ostream &o){
 void menuentry::add_entry(String sec, String fullsec, 
 			  map<String, String, less<String> > &v){
   if(dodebug)
-    cerr<<"ADDENTRY: sec="<<sec<<"needs="<<v["needs"]<<endl;
+    cerr<<"ADDENTRY: sec="<<sec<<", needs="<<v["needs"]<<endl;
   if(sec.length()!=0){
     String name;
     map <String, menuentry *, less<String> >::iterator i;
@@ -889,7 +893,7 @@ void menuentry::generate_hotkeys(){
   set<char, less<char> > used_chars;
   String s;
   char c;
-  
+
   if(config->hkexclude)
     s=config->hkexclude->soutput(vars);
   for(i=0;i!=s.length();i++)
@@ -1009,7 +1013,7 @@ void includemenus(String o, String i,
   if(!fo){
     cerr<<"Cannot open file "<<o<<endl; throw informed_fatal();}
 
-  try{
+  {
     while(fi.get(buf,sizeof(buf))){
       if(String(buf).contains(rep,0)){
 	while(fm.get(buf,sizeof(buf))){
