@@ -29,7 +29,7 @@ Example "str":
 #include <iostream.h>
 #include <vector.h>
 #include <map.h>
-#include <String.h>
+// #include <String.h>
 #include "../common.h"
 #include "../adstring.h"
 
@@ -39,7 +39,7 @@ class narg_mismatch:public parseerror{ //number of args mismatch to func.
 public:
   char name[MAX_LINE];
   narg_mismatch(parsestream *p,String s):parseerror(p){
-    strcpy(name,&(s[0]));
+    strcpy(name,s.chrstr());
   };
   const char *errormsg(){
     String s=String("Number of arguments to function ")+
@@ -64,7 +64,7 @@ class dir_createerror{ //number of args mismatch to func.
 public:
   char name[MAX_LINE];
   dir_createerror(String s){
-    strcpy(name,&(s[0]));
+    strcpy(name,s.chrstr());
   };
 };  
 
@@ -72,7 +72,7 @@ class missing_tag:public parseerror{
 public:
   char name[MAX_LINE];
   missing_tag(parsestream *p,String s):parseerror(p){
-    strcpy(name,&(s[0]));
+    strcpy(name,s.chrstr());
   };
   const char *errormsg(){
     String s=String("Missing (or empty) tag: ")+
