@@ -30,15 +30,15 @@ configinfo     config;
 DIR *open_dir_check(String dirname){
   struct stat st;
   dirname+='\0';
-  stat (&(dirname[0]), &st);
+  stat (dirname.chrstr(), &st);
   if (!S_ISDIR (st.st_mode))
-    throw dir_error_read(&(dirname[0]));
+    throw dir_error_read(dirname);
 
-  return opendir (&(dirname[0]));
+  return opendir (dirname);
 }
-bool executable(const char *s){
+bool executable(const String &s){
   struct stat st;
-  stat (s, &st);
+  stat (s.chrstr(), &st);
   return (((st.st_mode & S_IXOTH) || 
 	   ((st.st_mode & S_IXGRP) && st.st_gid == getegid ()) || 
 	   ((st.st_mode & S_IXUSR) && st.st_uid == geteuid ())) && 
@@ -71,29 +71,34 @@ bool menuentry::check_install(parsestream &i){
   i.skip_char(')');
   return true;
 }
+void menuentry::menuentry_constr_gccbug(parsestream &i)
+{ 
+  char c;
+  String name, val;
+  //new format menuentry
+  
+  //read available info
+  check_install(i);
+  i.skip_space();
+  i.skip_char(':');
+  //read menuentry:
+  try{
+    do{
+      name=i.get_name();
+      val=i.get_eq_Stringconst();
+      data[name]=val;
+      c=i.get_char();
+      i.put_back(c);
+    }while(c);
+  }
+  catch(endofline){};
+  i.skip_line();
+}
 menuentry::menuentry(parsestream &i, const String &filename){
   char c;
   c=i.get_char();
   if(c=='?'){
-    String name, val;
-    //new format menuentry
-    
-    //read available info
-    check_install(i);
-    i.skip_space();
-    i.skip_char(':');
-    //read menuentry:
-    try{
-      do{
-	name=i.get_name();
-	val=i.get_eq_Stringconst();
-	data[name]=val;
-	c=i.get_char();
-	i.put_back(c);
-      }while(c);
-    }
-    catch(endofline){};
-    i.skip_line();
+    menuentry_constr_gccbug(i);
   }else{
     //old format menuentry
     if(!test_installed(filename)){
@@ -125,7 +130,7 @@ void menuentry::output(vector<String> &s){
 	t+=" ";
     }
   t+="\n";
-  config.report(String("ADDING")+t,configinfo::report_debug);
+  config.report(String("ADDING: ")+t,configinfo::report_debug);
   s.push_back(t);
 }
 void menuentry::output_compat(vector<String> &s){
@@ -139,7 +144,7 @@ void menuentry::output_compat(vector<String> &s){
    +icon   +" \""
    +data[TITLE_VAR]  +"\" "
    +escape_String(data[COMMAND_VAR],"\n")+"\n";
-  config.report(String("ADDING")+t,configinfo::report_debug);
+  //config.report(String("ADDING:")+t,configinfo::report_debug);
   s.push_back(t);
 }
 ostream &menuentry::debugoutput(ostream &o){
@@ -237,7 +242,7 @@ void configinfo::report(const String &message,
       break;
     case method_syslog:
       openlog("update-menus",LOG_PID,syslog_facility);
-      syslog(syslog_priority,&(message[0]));
+      syslog(syslog_priority,message);
       closelog();
     }
   }
@@ -259,9 +264,8 @@ bool  trans_class::check(String &s){
   return match.contains(s,0);
 }
 
-ostream &trans_class::debuginfo(ostream &o){
-  o<<", match="<<match<<", replace="<<replace<<", replace_var="<<replace_var;
-  return o;
+String trans_class::debuginfo(){
+  return String(" match=")+match+", replace="+replace+", replace_var="+replace_var;
 }
 
 void translate::process( menuentry &m,
@@ -290,8 +294,8 @@ void translateinfo::init(parsestream &i){
   String name, match, replace, match_var, replace_var;
   Regex ident("[a-zA-Z_][a-zA-Z0-9_]*");
 
-    config.report(String("reading translate info in ")+i.filename(),
-		    configinfo::report_verbose);
+  config.report(String("Reading translate info in ")+i.filename(),
+		configinfo::report_verbose);
   try{
     name=i.get_name(ident);
     config.report(String("name=")+name,
@@ -305,9 +309,12 @@ void translateinfo::init(parsestream &i){
     i.skip_char('>');
     i.skip_space();
     replace_var=i.get_name(ident);
+    config.report(String("replace_var=")+replace_var,
+		  configinfo::report_debug);
+
     i.skip_line();
     while(true){
-      pair<const String, trans_class *> p;
+      trans_class *trcl;
 
       i.skip_space();
       match=i.get_Stringconst();
@@ -321,18 +328,27 @@ void translateinfo::init(parsestream &i){
       }
       i.skip_space();
       replace=i.get_Stringconst();
-      (String)p.first=match;
       if(name=TRANSLATE_TRANS)
-	p.second=new translate(match,replace,replace_var);
+	trcl=new translate(match,replace,replace_var);
       if(name=SUBTRANSLATE_TRANS)
-	p.second=new subtranslate(match,replace,replace_var);
+	trcl=new subtranslate(match,replace,replace_var);
       if(name=SUBSTITUTE_TRANS)
-	p.second=new substitute(match,replace,replace_var);
+	trcl=new substitute(match,replace,replace_var);
+
+      pair<const String, trans_class *> p(match,trcl);
+
+      config.report(String("adding translate rule: [")+p.first+
+		    "]"+ trcl->debuginfo(),
+		    configinfo::report_debug);
       trans[match_var].insert(p);
       i.skip_line();
     }
   }
-  catch (endoffile){}
+  catch (endoffile){};
+  
+  {config.report(String("End reading translate info"),
+		 configinfo::report_debug);}
+
 }
 
 translateinfo::translateinfo(parsestream &i){
@@ -353,10 +369,12 @@ void translateinfo::process(menuentry &m){
   for(i=trans.begin(); i!=trans.end(); i++){
     match=&m.data[(*i).first];
     j=(*i).second.upper_bound(*match);
-    config.report(String("translate: var[")+*match+"]",
-			 configinfo::report_debug);
     do{
       j--;
+      config.report(String("translate: var[")+*match+"]"+
+		    " testing trans rule match for:"+
+		    (*j).first,
+		    configinfo::report_debug);
       (*j).second->process(m,*match);
     } while((*j).second->check(*match)&&
 	    (j!=(*i).second.begin()));
@@ -372,8 +390,11 @@ void translateinfo::debuginfo(){
     for(j=(*i).second.begin();
 	j!=(*i).second.end();
 	j++){
-      config.report(String("key=")+(*j).first,configinfo::report_debug);
-      (*j).second->debuginfo(cerr);
+      config.report(String("key=")+(*j).first+
+		    (*j).second->debuginfo()+"\n",
+		    configinfo::report_debug);
+
+      
     }
   } 
 }
@@ -420,7 +441,7 @@ void read_pkginfo (const char *statusfile)
   fclose (status);
 }
 
-void read_menufile(const char *filename,
+void read_menufile(const String &filename,
 		   const String &shortfilename,
 		   vector<String> &menudata,
 		   vector<String> &menudata_compat){
@@ -439,7 +460,7 @@ void read_menufile(const char *filename,
     }
     else
       i=new parsestream(filename);
-    while(i->good()){
+    while(true){//i->good()){
       try{
 	menuentry m(*i,shortfilename);
 	if(transinfo)
@@ -470,25 +491,29 @@ void read_menufilesdir(const String &dirname,
   DIR *dir;
   struct dirent *entry;
   String name;
+  String dummy;
   config.report(String("Reading menuentryfiles  in ")+dirname,
 		configinfo::report_debug);
-  dir=open_dir_check(dirname);
-  while((entry=readdir(dir))){
-    name=String(entry->d_name);
-    if((name!="README")&&(name!="core")&&(name[0]!='.'))
-      if(menufiles_processed.find(name)==menufiles_processed.end()){
-	menufiles_processed.insert(name);
-	name=dirname+name;
-	stat(&(name[0]),&st);
+  try{
+    dir=open_dir_check(dirname);
+    while((entry=readdir(dir))){
+      name=String(entry->d_name);
+      if((name!="README")&&(name!="core")&&(name[0]!='.'))
+	if(menufiles_processed.find(name)==menufiles_processed.end()){
+	  menufiles_processed.insert(name);
+	  name=dirname+name;
+	  stat(name.chrstr(),&st);
 	if(S_ISREG(st.st_mode)||S_ISLNK(st.st_mode))
-	  read_menufile(&(name[0]),entry->d_name,
+	  read_menufile(name,entry->d_name,
 			menudata,menudata_compat);
-      }
-    
-  }
+	}
+      
+    }
+  } catch (dir_error_read p){dummy=p.name;}
+  
 }
 
-void run_menumethod(char *methodname,
+void run_menumethod(String methodname,//char *methodname,
 		    const vector<String> &menudata,
 		    const vector<String> &menudata_compat){
   ifstream m(methodname);
@@ -508,8 +533,8 @@ void run_menumethod(char *methodname,
     md=&menudata;
   config.report(String("Udate-menus: Running method:")+methodname,
 		configinfo::report_verbose);  
-  strcat(methodname," -f --stdin ");
-  if((p=popen(methodname, "w"))){
+  methodname+=" -f --stdin ";
+  if((p=popen(methodname.chrstr(), "w"))){
     signal(SIGPIPE,SIG_IGN);
     for(i=0;i!=md->size();i++){
       str=(*md)[i];
@@ -532,15 +557,17 @@ void run_menumethoddir (const String &dirname,
 		configinfo::report_verbose);
   dir=open_dir_check(dirname);
   while ((entry = readdir (dir)) != NULL){
-    if (!strcmp (entry->d_name, "README"))
+    if (!strcmp(entry->d_name, "README") ||
+	!strcmp(entry->d_name, "core"))
       continue;
-    for (s = entry->d_name; *s != '\0'; s++)
+    for (s = entry->d_name; *s != '\0'; s++){
       if (!(isalnum (*s) || (*s == '_') || (*s == '-')))
 	break;
+    }
     if (*s != '\0')
       continue;
     
-    sprintf (tmp, "%s/%s", &(dirname[0]), entry->d_name);
+    sprintf (tmp, "%s/%s", dirname.chrstr(), entry->d_name);
     stat (tmp, &st);
     
     // Do we have execute permissions? 
@@ -572,9 +599,9 @@ int kill_other_updatemenus(){
       t=p.get_Stringconst();
     }
     s="/proc/"+t+"/exe";
-    stat(&(s[0]),&st_other);
+    stat(s.chrstr(),&st_other);
     s="/proc/"+itoString(getpid())+"/exe";
-    stat(&(s[0]),&st_self);
+    stat(s.chrstr(),&st_self);
     if((st_self.st_dev==st_other.st_dev)&&
        (st_self.st_ino==st_other.st_ino)){
       int other_pid=Stringtoi(t);
@@ -750,7 +777,7 @@ main (int, char **argv){
 
     read_usertranslateinfo();
     read_roottranslateinfo();
-    if(debug)
+    if(transinfo)
       transinfo->debuginfo();
     if(getuid()){
       try{
@@ -765,7 +792,7 @@ main (int, char **argv){
     read_menufilesdir(MENUMENUS, menudata, menudata_compat);
     //menudata+='\0';
     //menudata_compat+='\0';
-
+    
     if(getuid()){
       try{
 	run_menumethoddir(String(getenv("HOME"))+"/"+USERMETHODS,
