@@ -26,14 +26,14 @@ class ferror_read{
 public:
   char name[MAX_LINE];
   ferror_read(String s){
-    strcpy(name,&(s[0]));
+    strcpy(name,s.chrstr());
   };
 };  //file open for reading failed
 class pipeerror_read{
 public:
   char name[MAX_LINE];
   pipeerror_read(String s){
-    strcpy(name,&(s[0]));
+    strcpy(name,s.chrstr());
   };
 };  //pipe open for reading failed
 
@@ -41,7 +41,7 @@ class dir_error_read{
 public:
   char name[MAX_LINE];
   dir_error_read(String s){
-    strcpy(name,&(s[0]));
+    strcpy(name,s.chrstr());
   };
 };  //dir open for reading failed
 
@@ -74,6 +74,7 @@ class menuentry {
 private:
   bool test_installed(String filename);
   bool check_install(parsestream &i);
+  void  menuentry_constr_gccbug(parsestream &i);
 public:
   map <String, String, less<String> > data;
   menuentry(parsestream &i, const String &);
@@ -95,7 +96,7 @@ public:
   
   virtual void process(menuentry &m,
 		       const String &v)=NULL;
-  ostream &debuginfo(ostream &);
+  String debuginfo();
 };
 class translate: public trans_class{
 public:
@@ -158,6 +159,7 @@ public:
   void update(String filename);
   void report(const String &message,verbosity_type v);
   void set_verbosity(verbosity_type v){verbosity=v;};
+  
 };
 
 
